==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sblock/hot5.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");
# hot 5 (    5)

unset($VAR);
$sql  = "SELECT * FROM T_Stories ORDER BY replys DESC LIMIT 5";
$hot5_result = SqlQuery($sql);
$hot5_nrows = mysql_num_rows($hot5_result);
$cnt = $cnt	+ $hot5_nrows;

if ($CONF['Hot5']>0 && $hot5_nrows>0) {
   $VAR['Heading'] = _HOT5;
   $VAR['Content'] = "";
   while ($A = mysql_fetch_array($hot5_result)) {
      $VAR["Content"]	.= "$CONF[dotchar]<A HREF=\"" . KWL_MakeStoryLink($A["Rid"]) . "\">$A[Heading]</A> (" . $A['replys'] . ")<BR>\n";
   }
   $VAR['Display'] =& $align;
   KWL_DrawBlock($VAR);
   mysql_free_result($hot5_result);
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/hot5.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");
# hot 5 (    5)

unset($VAR);
$sql  = "SELECT * FROM T_Stories ORDER BY replys DESC LIMIT 5";
$hot5_result = SqlQuery($sql);
$hot5_nrows = mysql_num_rows($hot5_result);
$cnt = $cnt	+ $hot5_nrows;

if ($CONF['Hot5']>0 && $hot5_nrows>0) {
   $VAR['Heading'] = _HOT5;
   $VAR['Content'] = "";
   while ($A = mysql_fetch_array($hot5_result)) {
      $VAR["Content"]	.= "$CONF[dotchar]<a href=\"" . KWL_MakeStoryLink($A["Rid"]) . "\">$A[Heading]</a> (" . $A['replys'] . ")<br />\n";
   }
   $VAR['Display'] =& $align;
   KWL_DrawBlock($VAR);
   mysql_free_result($hot5_result);
}
?>
